<?php
/*
Plugin Name: Cookie Timeout
Version: 0.41
Plugin URI: http://www.freemoby.com/2005/05/21/wordpress-plugin-cookie-timeout/
Description: Sets the amount of time before the login cookie will expire. <a href="options-general.php?page=cookietimeout.php">Options &raquo; Cookie Timeout</a>
Author: Michael Breland
Author URI: http://www.freemoby.com/
*/  
/*
Cookie Timeout - Sets the amount of time before the login cookie will expire.

This code is licensed under the MIT License.
http://www.opensource.org/licenses/mit-license.php
Copyright (c) 2005 -2008 Michael Breland

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the
Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to
do so, subject to the following conditions:

The above copyright notice and this permission notice shall
be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
if (is_plugin_page()):
  $wppCookieTimeout->options_page();
else:

// This check is needed the first time the plugin is activated to prevent a redeclare error.
if (!function_exists('wp_setcookie')) :
function wp_setcookie($username, $password, $already_md5 = false, $home = '', $siteurl = '', $remember = false) {
  if ( !$already_md5 )
  {
    $password = md5( md5($password) ); // Double hash the password in the cookie.
  }  

  if ( empty($home) )
  {
    $cookiepath = COOKIEPATH;
  }  
  else
  {
    $cookiepath = preg_replace('|https?://[^/]+|i', '', $home . '/' );
  }

  if ( empty($siteurl) ) 
  {
    $sitecookiepath = SITECOOKIEPATH;
    $cookiehash = COOKIEHASH;
  } 
    else 
  {
    $sitecookiepath = preg_replace('|https?://[^/]+|i', '', $siteurl . '/' );
    $cookiehash = md5($siteurl);
  }

  if ( $remember || (intval(get_option('cookie_timeout_override')) == 1 ) )
  {
    $cookie_timeout = intval(get_option('cookie_timeout'));
    if ($cookie_timeout <= 0)
    {
      $cookie_timeout = 31536000;
    }
    elseif ($cookie_timeout > 1)
    {
      $cookie_timeout += time();
    }
  }  
  else
  {
    $cookie_timeout = 1;
  } 
  
  if ($cookie_timeout == 1)
  {
    setcookie(USER_COOKIE, $username, NULL, $cookiepath, COOKIE_DOMAIN);
    setcookie(PASS_COOKIE, $password, NULL, $cookiepath, COOKIE_DOMAIN);
  
    if ( $cookiepath != $sitecookiepath ) 
    {
      setcookie(USER_COOKIE, $username, NULL, $sitecookiepath, COOKIE_DOMAIN);
      setcookie(PASS_COOKIE, $password, NULL, $sitecookiepath, COOKIE_DOMAIN);
    }
  }
  else
  {
    setcookie(USER_COOKIE, $username, $cookie_timeout, $cookiepath, COOKIE_DOMAIN);
    setcookie(PASS_COOKIE, $password, $cookie_timeout, $cookiepath, COOKIE_DOMAIN);
  
    if ( $cookiepath != $sitecookiepath ) 
    {
      setcookie(USER_COOKIE, $username, $cookie_timeout, $sitecookiepath, COOKIE_DOMAIN);
      setcookie(PASS_COOKIE, $password, $cookie_timeout, $sitecookiepath, COOKIE_DOMAIN);
    }
  }
}
endif;

class CookieTimeout
{
  var $days = 0;
  var $hours = 0;
  var $minutes = 0;
  var $seconds = 0;
  
  function CookieTimeout()
  {
    add_action('admin_menu', array(&$this, 'admin_menu'));
  }

  function admin_menu()
  {
    add_options_page( __('Cookie Timeout Options'), __('Cookie Timeout'), 5, basename(__FILE__));
  }

  function options_page()
  {
    if (isset($_POST['Submit'])):
     
      check_admin_referer('FreeMoby_Cookie_Timeout_Set_Values');
     
      $tempValue = intval($_POST['cookie_timeout_days']);
      if ($tempValue > 0)
      {
        $timeoutSeconds = $tempValue * 86400; 
      }
      $tempValue = intval($_POST['cookie_timeout_hours']);
      if ($tempValue > 0)
      {
        $timeoutSeconds = $timeoutSeconds + ($tempValue * 3600);  
      }
      $tempValue = intval($_POST['cookie_timeout_minutes']);
      if ($tempValue > 0)
      {
        $timeoutSeconds = $timeoutSeconds + ($tempValue * 60);  
      }
      if ($timeoutSeconds == 0)
      {
        $timeoutSeconds = 1; // Current browser session
      }
      else if ($timeoutSeconds < 300)
      {
        $timeoutSeconds = 300; // Don't let it go below 5 minutes
      }
      update_option('cookie_timeout',$timeoutSeconds);
      if ($_POST['cookie_timeout_override'] == "1" )
      {
        update_option('cookie_timeout_override',1);
      }
      else
      {
        update_option('cookie_timeout_override',0);
      }
?>
<div class="updated"><p><strong><?php _e('Changes saved.  You will need to ') ?><?php wp_loginout(); ?><?php _e(' for this change to take effect.') ?></strong></p></div>
<?php
    endif;

  $this->seconds = intval(get_option('cookie_timeout'));
  if ($this->seconds <= 0)
  {
    $this->seconds = 31536000;
  }
  $this->days = intval($this->seconds / 86400);
  $this->seconds = $this->seconds - ($this->days * 86400);
  $this->hours = intval($this->seconds  / 3600);
  $this->seconds = $this->seconds - ($this->hours * 3600);
  $this->minutes = intval($this->seconds / 60);
  $this->override = intval(get_option('cookie_timeout_override'));
  if ($this->override != 1)
  {
    $this->override = 0;
  }
?>
<div class="wrap">
<h2><?php echo __('Cookie Timeout Options'); ?></h2>
<form name="cookie_timeout" method="post" action="">
<?php
if ( function_exists('wp_nonce_field') )
{
  wp_nonce_field('FreeMoby_Cookie_Timeout_Set_Values');
}
?>
  <input type="hidden" name="action" value="update" />
  <input type="hidden" name="page_options" value="'cookie_timeout'" />
  <fieldset class="options">
    <legend><?php echo __('Cookie Timeouts'); ?></legend>
    <table cellspacing="2" cellpadding="5" class="editform">
      <tr valign="baseline">
      <th scope="row"><?php _e("Expire Admin cookie after") ?>:</th>
      <td><input name="cookie_timeout_days" type="text" id="cookie_timeout_days" value="<?php echo $this->days; ?>" size="3" align="right" /> day<?php if($this->days!=1) echo "s"; ?></td>
      <td><input name="cookie_timeout_hours" type="text" id="cookie_timeout_hours" value="<?php echo $this->hours; ?>" size="3" align="right" /> hour<?php if($this->hours!=1) echo "s"; ?></td>
      <td><input name="cookie_timeout_minutes" type="text" id="cookie_timeout_minutes" value="<?php echo $this->minutes; ?>" size="3" align="right" /> minute<?php if($this->minutes!=1) echo "s"; ?></td>
      <td><input name="cookie_timeout_override" type="checkbox" id="cookie_timeout_override" value="1" align="right" <?php if ( $this->override ) { echo "checked"; } ?>/> Ignore the login &quot;Remember me&quot; checkbox and always use these values.</td>
      </tr>
      </table>
    <p>NOTE: &nbsp;If all fields are set to zero, then the cookie will last until the current browser session is closed or you logout.</p>
  </fieldset>
  <p class="submit">
      <input type="submit" name="Submit" value="<?php _e('Update Options') ?> &raquo;" />
  </p>
</form>
</div>
<?php
  }
}

$wppCookieTimeout =& new CookieTimeout;

endif; // End plugin page
?>